#if defined _afk_control_included
  #endinput
#endif
#define _afk_control_included

/**
 * Check if player is afk
 *
 * @param id            Player index
 *
 * @return              true on success, false otherwise
 */
native afkc_is_user_afk(const id);

/**
 * Gets the current afk player status stage
 *
 * @param id            Player index
 *
 * @return              AFC stage as a percentage (from 0 to 100)
 */
native afkc_get_stage(id);

/**
 * Instant update of the player's last activity time
 *
 * @note The second parameter should include local game time (func: get_gametime())
 *       Use 0 to reset activity time
 *
 * @note The activity time is calculated for each new frame of the player
 *
 * @param id            Player index
 * @param time          New time
 *
 * @return              true on success, false otherwise
 */
native afkc_update_activity(const id, Float:time = 0.0);

/**
 * Сalled every new stage of the player's AFK
 *
 * @param id            Player index
 * @param lastActivity  The last time of the player's activity
 * @param stage         Current afk stage (can be overwritten)
 *
 * @noreturn
 */
forward afkc_stage(id, Float:lastActivity, &stage);

/**
 * Called before the plugin punishes the player for AFK
 *
 * @note The plugin doesn't update the time of the player's last activity,
 *       in case the event is blocked
 *
 * @param id            Player index
 *
 * @return      PLUGIN_CONTINUE to allow the action to happen
 *              PLUGIN_HANDLED or higher to prevent this action
 */
forward afkc_action(id);

/**
 * Called when the player's AFK status is switched
 *
 * @param id            Player index
 * @param status        If true the player is AFK, false otherwise
 *
 * @noreturn
 */
forward afkc_toggle(id, bool:status);